# ConnectifyCLI

## Running commands
1. Install package
```shell
pip install -e .
```
2. Run command download (dl)
```shell
connect dl sample_name
```

## Tests
Use pytest to run tests:
```python
pytest
```